@@ -9,7 +9,6 @@
 from .Route import Route
 from .Verb import Verb
 from ..Exceptions import *
-from parse import parse
 from singleton_decorator import singleton
 from confo.Confo import Confo
 import ctypes
@@ -24,6 +23,7 @@ class Router:
         self.routes = []
         self.urls = []
         self.configuration_manager = Confo()
+        self.flask_app = None
 
     def add_route(self, route: Route):
         """
@@ -48,40 +48,19 @@ class Router:
         if route_parameters["name"] in list([r["name"] for r in self.routes]): raise UniqueNameException(
             " Use unique route names, " + route_parameters["name"] + " already exists.")
 
-    def find_route(self, request):
+    def load_flask_app(self,flask_app):
         """
-        This method to search for a route that matches the request
-        :param request:
+         Load flask app into the routing system
+        :param flask_app:
         :return:
         """
-
-        def method_validator(request_method, route_method):
-            """
-            This method is used to validate if HTTP verbs match
-            :param request_method:
-            :param route_method:
-            :return:
-            """
-            if Verb().validate(request_method) == route_method:
-                return True
-            else:
-                return False
-
-        request_path = request.path
-        if request_path.strip().lower() != "/":
-            request_path = request_path.rstrip("/")
-
+        self.flask_app = flask_app
         for route in self.routes:
-            parse_result = parse(route["url"], request_path)
-            if parse_result is not None:
-                return (route, parse_result.named) if method_validator(request.method, route["verb"]) else (None, None)
-            else:
-                parse_result = parse(route["url"].rstrip("/"), request_path.rstrip("/"))
-                if parse_result is not None:
-                    return (route, parse_result.named) if method_validator(request.method, route["verb"]) else (
-                    None, None)
+            self.flask_app.add_url_rule(rule=route['url'],
+                                        endpoint=route['name'],
+                                        view_func=self.build_handler(route),
+                                        methods=[Verb().get_string(route['verb'])])
 
-        return None, None
 
     def register_routes(self, route_paths):
         """
@@ -120,10 +99,11 @@ class Router:
         if Controller == "SegoBaseController":
             handler_id = self.configuration_manager.get("dynamic_routes", action)
             handler = ctypes.cast(handler_id, ctypes.py_object).value
-            return handler
+        else:
+            _class = self.dynamic_import(Controller)
+            handler = getattr(_class(),action)
 
-        _class = self.dynamic_import(Controller)
-        return getattr(_class(), action)
+        return handler
 
     def get_routes(self):
         """
