@@ -5,7 +5,7 @@
 # Original Date:            10 March 2021                                 #
 # Version:                  0.1.0                                         #
 # ************************************************************************#
-
+from .. import Routing
 from ..Exceptions.HTTPVerbException import UnknownHTTPMethodException
 class Verb:
     HTTP_GET = 1
@@ -26,3 +26,17 @@ class Verb:
         else:
             raise UnknownHTTPMethodException()
 
+    def get_string(self,verb):
+        if verb == self.HTTP_GET:
+            return 'GET'
+        elif verb == self.HTTP_POST:
+            return 'POST'
+        elif verb == self.HTTP_PUT:
+            return 'PUT'
+        elif verb == self.HTTP_DELETE:
+            return 'DELETE'
+        else:
+            raise UnknownHTTPMethodException()
+
+
+
